Imports System.Data.Linq
Imports LinqBlog.BO

Partial Class DefaultPage
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        If Not Page.IsPostBack Then
            If Request.QueryString.Count > 0 Then
                If Request.QueryString("Page") <> "" Then
                    Dim PageNo As Integer
                    If Integer.TryParse(Request.QueryString("Page"), PageNo) Then
                        ShowPagedData(PageNo)
                    End If
                End If
                If Request.QueryString("Title") <> "" Then
                    ShowPostByTitle()
                ElseIf Request.QueryString("CategoryId") <> "" Then
                    Dim Id As Integer
                    If Integer.TryParse(Request.QueryString("CategoryId"), Id) Then
                        ShowCategoryPosts(Id)
                    End If
                End If
                If Request.QueryString("PostId") <> "" Then
                    Dim dc As New LinqBlogEntities
                    Me.Repeater1.DataSource = From post In dc.PostItems.Include("Categories").Include("Comments") _
                        Where post.Id = Request.QueryString("PostId") _
                        Select post
                End If
            Else
                ShowPagedData(1)
            End If
            Me.Repeater1.DataBind()
        End If
    End Sub

    Private Sub ShowPagedData(ByVal PageNo As Integer)
        Dim dc As New LinqBlogEntities

        Dim posts = From post In dc.PostItems.Include("Categories").Include("Comments") _
                    Order By post.PublicationDate Descending _
                    Select post
        Dim paged = posts.Skip(5 * (PageNo - 1)).Take(5)

        Repeater1.DataSource = paged

        SetPagingButtons(PageNo)
    End Sub

    Protected Function IsAdmin() As Boolean
        Return My.User.IsInRole("Admin")
    End Function

    Private Sub SetPagingButtons(ByVal PageNo As Integer)
        If PageNo > 1 Then
            Previous.Visible = True
            Me.Previous.NavigateUrl = "~/Default.aspx?Page=" & (PageNo - 1).ToString
        Else
            Previous.Visible = False
        End If

        Me.Next.NavigateUrl = "~/Default.aspx?Page=" & (PageNo + 1).ToString
    End Sub

    Private Sub ShowCategoryPosts(ByVal categoryid As Integer)
        Dim dc As New LinqBlogEntities
        Dim query = From p In dc.PostItems.Include("Categories").Include("Comments") _
                    Where p.Categories.Any(Function(c) c.CategoryId = categoryid) _
                    Select p

        Me.Repeater1.DataSource = query

    End Sub

    Private Sub ShowPostByTitle()
        Dim RequestTitle As String = Replace(Request.QueryString("Title"), "_", " ")
        RequestTitle = Replace(RequestTitle, "-", " ")

        Dim dc As New LinqBlogEntities
        'Strip off .aspx
        RequestTitle = Replace(RequestTitle, ".aspx", "")
        Dim posts = (From post In dc.PostItems.Include("Categories").Include("Comments") _
                     Where post.Title = RequestTitle _
                     Select post).ToArray
        Me.Repeater1.DataSource = posts
        If posts.Count > 0 Then
            Me.CommentRegion.Visible = True
            PagingButtons.Visible = False

            Me.CommentRepeater.DataSource = From c In posts(0).Comments _
                                            Where c.IsApproved _
                                          Order By c.EnteredDate _
                                          Select c
            Me.CommentRepeater.DataBind()
            Session("CurrentPost") = posts(0)
            'Also add this to the page title
            ShowPageTitle(posts(0))
        End If
    End Sub

    Private Sub ShowPageTitle(ByVal post As PostItem)
        'Also add this to the page title
        Me.Title = "ThinqLinq - " & post.Title
    End Sub

    Protected Function GetCreator(ByVal link As String, ByVal creator As String) As String
        If link.Length > 0 Then
            Return "<a href='" & link & "' target='_blank'>" & creator & "</a>"
        Else
            Return creator
        End If
    End Function
End Class
