Option Strict On

Imports System.Linq
Imports System.Data.Linq
Imports LinqBlog.BO

Partial Class Admin_EditPost
    Inherits System.Web.UI.Page

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        If Not Page.IsPostBack Then

            Dim dc As New LinqBlogDataContext

            DisplayCategories(dc)

            Dim post As PostItem
            Dim id As Integer = GetPostId()
            If id > 0 Then
                post = (From p In dc.PostItems _
                    Where p.Id = id _
                    Select p).FirstOrDefault()
            Else
                post = New PostItem
                post.PublicationDate = Now
            End If

            DisplayPost(post)
            Session("CurrentPost") = post

        End If
    End Sub

    Protected Sub btnUpdate_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnUpdate.Click
        Dim dc As New LinqBlogDataContext

        Dim post As PostItem = TryCast(Session("CurrentPost"), PostItem)
        If post Is Nothing OrElse post.Id = 0 Then
            'New post
            post = New PostItem
            post.PublicationDate = Now()
            dc.PostItems.InsertOnSubmit(post)
        Else
            'Existing post
            post = (From p In dc.PostItems Where p.Id = post.Id).First
        End If

        post.Title = Me.txtTitle.Text
        post.Description = Me.FreeTextBox1.Text
        post.Author = "Jim Wooley"
        post.PublicationDate = CDate(Me.PublicationDate.Text)

        'Add categories
        For Each item In CategoryList.Items.OfType(Of ListItem)()
            Dim thisCategoryId As Integer = CInt(item.Value)
            If item.Selected Then
                If Not post.CategoryPosts.Where(Function(cp) (cp.CategoryID = thisCategoryId)).Count > 0 Then
                    'not in list, add it
                    post.CategoryPosts.Add(New CategoryPost With {.CategoryID = thisCategoryId})
                End If
            Else
                'Not selected. make sure to remove it if it is in the list
                dc.CategoryPosts.DeleteAllOnSubmit(From c In post.CategoryPosts Where c.CategoryID = thisCategoryId)
            End If
        Next
        dc.SubmitChanges()

        Response.Redirect("~/Default.aspx")
    End Sub

    Protected Sub btnDelete_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnDelete.Click
        Dim dc As New LinqBlogDataContext
        Dim post As PostItem = TryCast(Session("CurrentPost"), PostItem)
        If Not post Is Nothing Then
            post = (From p In dc.PostItems Where p.Id = post.Id).First
            dc.CategoryPosts.DeleteAllOnSubmit(post.CategoryPosts)
            dc.PostItems.DeleteOnSubmit(post)
            dc.SubmitChanges()
        End If
        Response.Redirect("~/Default.aspx")
    End Sub

    Private Function GetPostId() As Integer
        If Request.QueryString.Count > 0 Then
            Dim id As String = Request.QueryString("PostId")
            Dim WorkingId As Integer
            If Integer.TryParse(id, WorkingId) Then
                Return WorkingId
            Else
                Return 0
            End If
        End If
    End Function

    Private Sub DisplayCategories(ByVal dc As LinqBlogDataContext)
        Me.CategoryList.DataSource = From c In dc.Categories _
         Select c _
         Order By c.Description
        Me.CategoryList.DataTextField = "Description"
        Me.CategoryList.DataValueField = "CategoryId"
        CategoryList.DataBind()
    End Sub

    Private Sub DisplayPost(ByVal post As PostItem)
        If Not post Is Nothing Then
            Me.txtTitle.Text = post.Title
            Me.FreeTextBox1.Text = post.Description
            PublicationDate.Text = post.PublicationDate.ToString
            'set categories
            For Each c In post.CategoryPosts
                For i As Integer = 0 To CategoryList.Items.Count - 1
                    If c.CategoryID = CInt(CategoryList.Items(i).Value) Then
                        CategoryList.Items(i).Selected = True
                        Exit For
                    End If
                Next
            Next
        Else
            Me.txtTitle.Text = "Not found"
        End If
    End Sub


    Protected Sub btnImport_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnImport.Click
        Importer.ImportFeedNew()
    End Sub

    Protected Sub btnImportComments_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnImportComments.Click
        Importer.ImportComments()
    End Sub
End Class
